@@ -88,6 +88,11 @@
         <source>About</source>
         <translation type="unfinished">Acerca de</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Broken Symlink!</source>
+        <translation type="unfinished">Enlace perdido!</translation>
+    </message>
 </context>
 <context>
     <name>BookWindow</name>
@@ -563,6 +568,16 @@
         <source>Sort</source>
         <translation type="unfinished">Ordenar</translation>
     </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Ascending</source>
+        <translation type="unfinished">Ascendente</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Descending</source>
+        <translation type="unfinished">Descendente</translation>
+    </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Name (A-Z)</source>
